@@ -1,5 +1,5 @@
 from __future__ import print_function
-from aiohttp import ClientSession
+import requests
 from asyncio import get_event_loop, AbstractEventLoop
 from json import loads
 
@@ -9,9 +9,9 @@ class Client:
     """
     API client for gtchecker.com
     """
-    def __init__(self, token: str = None, *, loop:AbstractEventLoop=None):
+    def __init__(self, token: str = None, *):
         self.token = token
-        self.session = ClientSession(loop=loop if loop else get_event_loop())
+        
 
     async def get_gamertag(self, gamertag: str):
         """
@@ -20,8 +20,9 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await self.session.post("https://gtchecker.com/api/v1/xbox?gamertag={}".format(gamertag), headers=headers)
-
+        r = await request.post("https://gtchecker.com/api/v1/xbox?gamertag={}".format(gamertag), headers=headers)
+        data = loads(await r.text())
+        return data
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
             
@@ -32,8 +33,9 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await self.session.post("https://gtchecker.com/api/v1/psn?psn={}".format(psn), headers=headers)
-
+        r = await request.post("https://gtchecker.com/api/v1/psn?psn={}".format(psn), headers=headers)
+        data = loads(await r.text())
+        return data
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
 
